###
Copyright (c) 2002-2011 "Neo Technology,"
Network Engine for Objects in Lund AB [http://neotechnology.com]

This file is part of Neo4j.

Neo4j is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.
###

define( 
  ['./views/DashboardView'
   './models/ServerPrimitives'
   './models/DiskUsage'
   './models/CacheUsage'
   './models/ServerStatistics'
   './models/DashboardState'
   './models/KernelBean'
   'lib/backbone'],
  (DashboardView, ServerPrimitives, DiskUsage, CacheUsage, ServerStatistics, DashboardState, KernelBean) ->
  
    class DashboardController extends Backbone.Controller
      routes : 
        "" : "dashboard"

      initialize : (appState) =>
        @appState = appState

      dashboard : =>
        @appState.set( mainView : @getDashboardView() )

      getDashboardView : =>
        @view ?= new DashboardView  
          state      : @appState
          dashboardState : @getDashboardState()
          primitives : @getServerPrimitives()
          diskUsage  : @getDiskUsage()
          cacheUsage : @getCacheUsage()
          statistics : @getServerStatistics()
          kernelBean : @getKernelBean()

      getServerPrimitives : =>
        @serverPrimitives ?= new ServerPrimitives( server : @appState.getServer(), pollingInterval : 5000 )

      getKernelBean : =>
        @kernelBean ?= new KernelBean( server : @appState.getServer(), pollingInterval : 10000 )

      getDiskUsage : =>
        @diskUsage ?= new DiskUsage( server : @appState.getServer(), pollingInterval : 5000 )

      getCacheUsage : =>
        @cacheUsage ?= new CacheUsage( server : @appState.getServer(), pollingInterval : 5000 )
      
      getServerStatistics : =>
        @serverStatistics ?= new ServerStatistics( server : @appState.getServer() )
      
      getDashboardState : =>
        @dashboardState ?= new DashboardState( server : @appState.getServer() )

)
